@@ -75,7 +75,7 @@ sub requires {
 	'Exporter'	=> 5.64,
 	'IO::File'	=> 0,
 	'POSIX'		=> 0,
-	'Scalar::Util'	=> 0,
+	'Scalar::Util'	=> 1.22,	# For looks_like_number
 	'Storable'	=> 0,
 	'base'		=> 0,
 	'constant'	=> 0,
@@ -210,7 +210,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2018 by Thomas R. Wyant, III
+Copyright (C) 2010-2019 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
